==> opentelemetry-api-1.10.0-rc.1-sources.jar: io/opentelemetry/api/metrics/LongUpDownCounterBuilder.java <==
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */

package io.opentelemetry.api.metrics;

import java.util.function.Consumer;

/** Builder class for {@link LongUpDownCounter}. */
public interface LongUpDownCounterBuilder {
  /**
   * Sets the description for this instrument.
   *
   * <p>Description strings should follow the instrument description rules:
   * https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/metrics/api.md#instrument-description
   */
  LongUpDownCounterBuilder setDescription(String description);

  /**
   * Sets the unit of measure for this instrument.
   *
   * <p>Unit strings should follow the instrument unit rules:
   * https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/metrics/api.md#instrument-unit
   */
  LongUpDownCounterBuilder setUnit(String unit);

  /** Sets the counter for recording {@code double} values. */
  DoubleUpDownCounterBuilder ofDoubles();

  /**
   * Builds and returns a {@code LongUpDownCounter} with the desired options.
   *
   * @return a {@code LongUpDownCounter} with the desired options.
   */
  LongUpDownCounter build();

  /**
   * Builds this asynchronous instrument with the given callback.
   *
   * <p>The callback will only be called when the {@link Meter} is being observed.
   *
   * <p>Callbacks are expected to abide by the following restrictions:
   *
   * <ul>
   *   <li>Run in a finite amount of time.
   *   <li>Safe to call repeatedly, across multiple threads.
   * </ul>
   *
   * @param callback A state-capturing callback used to observe values on-demand.
   */
  void buildWithCallback(Consumer<ObservableLongMeasurement> callback);
}

==> opentelemetry-api-1.10.1-sources.jar: io/opentelemetry/api/metrics/LongUpDownCounterBuilder.java <==
/*
 * Copyright The OpenTelemetry Authors
 * SPDX-License-Identifier: Apache-2.0
 */

package io.opentelemetry.api.metrics;

import java.util.function.Consumer;

/** Builder class for {@link LongUpDownCounter}. */
public interface LongUpDownCounterBuilder {
  /**
   * Sets the description for this instrument.
   *
   * <p>Description strings should follow the instrument description rules:
   * https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/metrics/api.md#instrument-description
   */
  LongUpDownCounterBuilder setDescription(String description);

  /**
   * Sets the unit of measure for this instrument.
   *
   * <p>Unit strings should follow the instrument unit rules:
   * https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/metrics/api.md#instrument-unit
   */
  LongUpDownCounterBuilder setUnit(String unit);

  /** Sets the counter for recording {@code double} values. */
  DoubleUpDownCounterBuilder ofDoubles();

  /**
   * Builds and returns a {@code LongUpDownCounter} with the desired options.
   *
   * @return a {@code LongUpDownCounter} with the desired options.
   */
  LongUpDownCounter build();

  /**
   * Builds this asynchronous instrument with the given callback.
   *
   * <p>The callback will only be called when the {@link Meter} is being observed.
   *
   * <p>Callbacks are expected to abide by the following restrictions:
   *
   * <ul>
   *   <li>Run in a finite amount of time.
   *   <li>Safe to call repeatedly, across multiple threads.
   * </ul>
   *
   * @param callback A state-capturing callback used to observe values on-demand.
   */
  ObservableLongUpDownCounter buildWithCallback(Consumer<ObservableLongMeasurement> callback);
}
